==> tspair_1.2.0.zip: tspair/doc/tsp.R <==
###################################################
### chunk number 1: 
###################################################
library(tspair)
data(tspdata)
dim(dat)


###################################################
### chunk number 2: 
###################################################
tsp1 <- tspcalc(dat,grp)
tsp1


###################################################
### chunk number 3: 
###################################################
tsp2 <- tspcalc(eSet1,grp)
tsp3 <- tspcalc(eSet1,1)


###################################################
### chunk number 4: 
###################################################
tspplot(tsp1)


###################################################
### chunk number 5: 
###################################################
out <- tspsig(dat,grp,B=50,seed=12355)
out$p
out$nullscores


###################################################
### chunk number 6: 
###################################################
summary(tsp1,printall=TRUE) 


###################################################
### chunk number 7: 
###################################################
predict(tsp1,eSet2)
predict(tsp1,dat2)


###################################################
### chunk number 8: 
###################################################
narrays <- ncol(dat)
correct.prediction <- rep(TRUE,narrays)

for(i in 1:narrays){
	testdat <- dat[ , -i]
	testgrp <- grp[-i]
	tsptest <- tspcalc(testdat,testgrp)
	prediction <- predict(tsptest,dat)[i]
	correct.prediction[i] <- prediction == grp[i]
}
cv.error <- mean(correct.prediction==FALSE)
cv.error

==> tspair_1.8.0.zip: tspair/doc/tsp.R <==
###################################################
### chunk number 1: 
###################################################
#line 56 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfHE2YX/R.INSTALLd566244/tspair/inst/doc/tsp.Rnw"
library(tspair)
data(tspdata)
dim(dat)


###################################################
### chunk number 2: 
###################################################
#line 67 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfHE2YX/R.INSTALLd566244/tspair/inst/doc/tsp.Rnw"
tsp1 <- tspcalc(dat,grp)
tsp1


###################################################
### chunk number 3: 
###################################################
#line 76 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfHE2YX/R.INSTALLd566244/tspair/inst/doc/tsp.Rnw"
tsp2 <- tspcalc(eSet1,grp)
tsp3 <- tspcalc(eSet1,1)


###################################################
### chunk number 4: 
###################################################
#line 85 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfHE2YX/R.INSTALLd566244/tspair/inst/doc/tsp.Rnw"
tspplot(tsp1)


###################################################
### chunk number 5: 
###################################################
#line 96 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfHE2YX/R.INSTALLd566244/tspair/inst/doc/tsp.Rnw"
out <- tspsig(dat,grp,B=50,seed=12355)
out$p
out$nullscores


###################################################
### chunk number 6: 
###################################################
#line 107 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfHE2YX/R.INSTALLd566244/tspair/inst/doc/tsp.Rnw"
summary(tsp1,printall=TRUE) 


###################################################
### chunk number 7: 
###################################################
#line 113 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfHE2YX/R.INSTALLd566244/tspair/inst/doc/tsp.Rnw"
predict(tsp1,eSet2)
predict(tsp1,dat2)


###################################################
### chunk number 8: 
###################################################
#line 122 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpfHE2YX/R.INSTALLd566244/tspair/inst/doc/tsp.Rnw"
narrays <- ncol(dat)
correct.prediction <- rep(TRUE,narrays)

for(i in 1:narrays){
	testdat <- dat[ , -i]
	testgrp <- grp[-i]
	tsptest <- tspcalc(testdat,testgrp)
	prediction <- predict(tsptest,dat)[i]
	correct.prediction[i] <- prediction == grp[i]
}
cv.error <- mean(correct.prediction==FALSE)
cv.error
